/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIWindowCreator2.idl
 */

#ifndef __gen_nsIWindowCreator2_h__
#define __gen_nsIWindowCreator2_h__


#ifndef __gen_nsIWindowCreator_h__
#include "nsIWindowCreator.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIWebBrowserChrome; /* forward declaration */


/* starting interface:    nsIWindowCreator2 */
#define NS_IWINDOWCREATOR2_IID_STR "f673ec81-a4b0-11d6-964b-eb5a2bf216fc"

#define NS_IWINDOWCREATOR2_IID \
  {0xf673ec81, 0xa4b0, 0x11d6, \
    { 0x96, 0x4b, 0xeb, 0x5a, 0x2b, 0xf2, 0x16, 0xfc }}

class NS_NO_VTABLE nsIWindowCreator2 : public nsIWindowCreator {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IWINDOWCREATOR2_IID)

  /**
   * Definitions for contextFlags
   */
  enum { PARENT_IS_LOADING_OR_RUNNING_TIMEOUT = 1U };

  /** Create a new window. Gecko will/may call this method, if made
      available to it, to create new windows.
      @param parent parent window, if any. null if not. the newly created
                    window should be made a child/dependent window of
                    the parent, if any (and if the concept applies
                    to the underlying OS).
      @param chromeFlags chrome features from nsIWebBrowserChrome
      @param contextFlags flags about the context of the window being created.
      @return the new window
  */
  /* [noscript] nsIWebBrowserChrome createChromeWindow2 (in nsIWebBrowserChrome parent, in PRUint32 chromeFlags, in PRUint32 contextFlags); */
  NS_IMETHOD CreateChromeWindow2(nsIWebBrowserChrome *parent, PRUint32 chromeFlags, PRUint32 contextFlags, nsIWebBrowserChrome **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIWINDOWCREATOR2 \
  NS_IMETHOD CreateChromeWindow2(nsIWebBrowserChrome *parent, PRUint32 chromeFlags, PRUint32 contextFlags, nsIWebBrowserChrome **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIWINDOWCREATOR2(_to) \
  NS_IMETHOD CreateChromeWindow2(nsIWebBrowserChrome *parent, PRUint32 chromeFlags, PRUint32 contextFlags, nsIWebBrowserChrome **_retval) { return _to CreateChromeWindow2(parent, chromeFlags, contextFlags, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIWINDOWCREATOR2(_to) \
  NS_IMETHOD CreateChromeWindow2(nsIWebBrowserChrome *parent, PRUint32 chromeFlags, PRUint32 contextFlags, nsIWebBrowserChrome **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->CreateChromeWindow2(parent, chromeFlags, contextFlags, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsWindowCreator2 : public nsIWindowCreator2
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIWINDOWCREATOR2

  nsWindowCreator2();
  virtual ~nsWindowCreator2();
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsWindowCreator2, nsIWindowCreator2)

nsWindowCreator2::nsWindowCreator2()
{
  /* member initializers and constructor code */
}

nsWindowCreator2::~nsWindowCreator2()
{
  /* destructor code */
}

/* [noscript] nsIWebBrowserChrome createChromeWindow2 (in nsIWebBrowserChrome parent, in PRUint32 chromeFlags, in PRUint32 contextFlags); */
NS_IMETHODIMP nsWindowCreator2::CreateChromeWindow2(nsIWebBrowserChrome *parent, PRUint32 chromeFlags, PRUint32 contextFlags, nsIWebBrowserChrome **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIWindowCreator2_h__ */
